%%
%% This is file `title-WWUM.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% uni-titlepage.dtx  (with options: `driver,WWUM')
%% Copyright (c) 2009-2022 by Markus Kohm <komascript(at)gmx.info>
%% 
%% This file was generated from file(s) of uni-titlepage distribution.
%% 
%% ----------------------------------------------------------------------
%% 
%% This work may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License, version 1.3c of the license.
%% The latest version of this license is in
%%   http://www.latex-project.org/lppl.txt
%% and version 1.3c or later is part of all distributions of LaTeX
%% version 2005/12/01 or later.
%% 
%% This work has the LPPL maintenance status "maintained".
%% 
%% The Current Maintainer and author of this work is Markus Kohm.
%% 
%% This file may only be distributed together with
%% the file `uni-titlepage.dtx'.
%% You may however distribute the file `uni-titlepage.dtx' without this file.
%% 
\ProvidesFile{%
  title%
  -WWUM%
 .def%
}[%
2025-08-12 v1.4
KOMA presents the title page project
]
\begingroup
  \def\PackageNotLoadedError#1{%
    \GenericError{%
      (#1)\@spaces\@spaces\@spaces\@spaces
    }{%
      File `#1' Error: package `uni-titlepage' hasn't been loaded%
    }{%
      This definition file was made to be loaded by package
      `uni-titlepage'.\MessageBreak
      You may not use it without package `uni-titlepage'!\MessageBreak
      See the documentation of package `uni-titlepage' for explanation.%
    }%
  }%
  \ifx\csname uni-titlepage.sty@vers\endcsname\relax
    \PackageNotLoadedError{%
      title-WWUM.def%
    }%
  \fi
\endgroup
\DefineFamilyMember[%
  WWUM%
]{title}
\providecommand*{\presentationinformationWWUM}{%
  \usenonemptytitleelement{subject}\\
  to the Aquisition of the Academic Degree\\
  \usenonemptytitleelement{academicgrade}\\
  of the \usenonemptytitleelement{science} of \usenonemptytitleelement{discipline}\\
  of the \usenonemptytitleelement{faculty} faculty\\
  of the \usenonemptytitleelement{university}%
}
\providecaptionname{american,australian,british,canadian,%
  english,newzealand,UKenglish,USenglish}{\presentationinformationWWUM}{%
  \usenonemptytitleelement{subject}\\
  to the Aquisition of the Academic Degree\\
  \usenonemptytitleelement{academicgrade}\\
  of the \usenonemptytitleelement{science} of \usenonemptytitleelement{discipline}\\
  of the \usenonemptytitleelement{faculty} faculty\\
  of the \usenonemptytitleelement{university}%
}
\providecaptionname{german,ngerman,austrian,naustrian,%
  swissgerman,nswissgerman}{\presentationinformationWWUM}{%
  \usenonemptytitleelement{subject}\\
  zur Erlangung des \usenonemptytitleelement{academicgrade}\\
  der \usenonemptytitleelement{science} im Fachbereich
  \usenonemptytitleelement{discipline}\\
  der \usenonemptytitleelement{faculty} Fakult\"at\\
  der \usenonemptytitleelement{university}%
}
\NowButAfterBeginDocument
{%
  \providecaptionname{german,ngerman,austrian,naustrian,
    swissgerman,nswissgerman}{\presentedbyname}{vorgelegt von}%
  \scr@ifundefinedorrelax{captionsgerman}{}{%
    \renewcaptionname{german}{\presentedbyname}{vorgelegt von}%
    \renewcaptionname{german}{\ordinalfemalerefereename}{%
      \ordinalfemalecorrectorname}%
  }%
  \scr@ifundefinedorrelax{captionsngerman}{}{%
    \renewcaptionname{ngerman}{\presentedbyname}{vorgelegt von}%
    \renewcaptionname{ngerman}{\ordinalmalerefereename}{%
      \germanordinalmalecorrectorname}%
    \renewcaptionname{ngerman}{\ordinalfemalerefereename}{%
      \germanordinalfemalecorrectorname}%
  }%
  \scr@ifundefinedorrelax{captionsaustrian}{}{%
    \renewcaptionname{austrian}{\presentedbyname}{vorgelegt von}%
    \renewcaptionname{austrian}{\ordinalmalerefereename}{%
      \germanordinalmalecorrectorname}%
    \renewcaptionname{austrian}{\ordinalfemalerefereename}{%
      \germanordinalfemalecorrectorname}%
  }%
  \scr@ifundefinedorrelax{captionsnaustrian}{}{%
    \renewcaptionname{naustrian}{\presentedbyname}{vorgelegt von}%
    \renewcaptionname{naustrian}{\ordinalmalerefereename}{%
      \germanordinalmalecorrectorname}%
    \renewcaptionname{naustrian}{\ordinalfemalerefereename}{%
      \germanordinalfemalecorrectorname}%
  }%
  \scr@ifundefinedorrelax{captionsswissgerman}{}{%
    \renewcaptionname{swissgerman}{\presentedbyname}{vorgelegt von}%
    \renewcaptionname{swissgerman}{\ordinalmalerefereename}{%
      \germanordinalmalecorrectorname}%
    \renewcaptionname{swissgerman}{\ordinalfemalerefereename}{%
      \germanordinalfemalecorrectorname}%
  }%
  \scr@ifundefinedorrelax{captionsnswissgerman}{}{%
    \renewcaptionname{nswissgerman}{\presentedbyname}{vorgelegt von}%
    \renewcaptionname{nswissgerman}{\ordinalmalerefereename}{%
      \germanordinalmalecorrectorname}%
    \renewcaptionname{nswissgerman}{\ordinalfemalerefereename}{%
      \germanordinalfemalecorrectorname}%
  }%
}
\renewcommand*{\inittitle}{%
  \ifx\@university\@empty
    \university{%
      Westf\"alischen Wilhelms-Universit\"at M\"unster%
    }%
  \fi
  \ifx\@place\@empty
    \place{%
      \PackageError{uni-titlepage}{Birth `place' missing}{%
        Style `WWUM' needs the birth place of the student, so option `place=...'
        resp.\MessageBreak
        command `\string\place{...}' is mandatory}%
    }
  \fi
  \ifx\@titlepagefont\@empty
    \renewcommand*{\@titlepagefont}{\normalfont\large}%
  \fi
}
\renewcommand*{\makemaintitle}{%
  \begin{%
    titlepage}
    \setlength{\parskip}{\z@}%
    \setlength{\parindent}{\z@}%
    \setlength{\parfillskip}{\z@\@plus 1fil}%
    \linespread{1}\selectfont
    \@titlepagefont
    \centering
    \usenonemptytitleelement{chair}\\
    \vspace{2cm}
    \usenonemptytitleelement{title}\\
    \vfill
    \presentationinformationWWUM\\
    \vfill
    \presentedbyname\\
    \usenonemptytitleelement{author}\\
    \ifx\@place\@empty\else\fromplacename{} \@place\\\fi
    --\,\the\year\,--
  \end{%
    titlepage}
}
\renewcommand*{\makemaintitleback}{%
  \begin{titlepage}
    \setlength{\parfillskip}{\z@\@plus 1fil}%
    \vspace*{\fill}
    \noindent
    \@tempcnta\z@
    \def\arraystretch{2}%
    \newcommand*{\test@malefemale}[1][m]{%
      \global\advance\@tempcnta by\@ne
      \Ifstr{##1}{f}{\def\fe@male{female}}{\def\fe@male{male}}%
      \csname \fe@male ordinal\endcsname{\@tempcnta}\space
      \csname \fe@male refereename\endcsname: &
      \def\and{\\\test@malefemale}%
    }%
    \begin{tabular}{@{}ll@{}}
      \chairmanname: & \@professor \\
      \expandafter\test@malefemale
      \@referee \\
      \oralexaminationdatename: & \@oralexaminationdate
      \ifx\examinationdatename\@empty\else
        \\\examinationdatename:     &
      \fi
      \\
    \end{tabular}
  \end{titlepage}
}
\renewcommand*{\makepretitle}{%
  \begin{fullsizetitle}
    \@titlepagefont
    \vspace*{.33\vsize}%

    \centering
    \usenonemptytitleelement{author}\\[1ex]
    \usenonemptytitleelement{title}\\[1ex]
    \the\year
  \end{fullsizetitle}
}
\renewcommand*{\makepretitleback}{%
  \if@twoside\begin{titlepage}\null\end{titlepage}\fi
}
\endinput
%%
%% End of file `title-WWUM.def'.
